document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const mobileMenu = document.querySelector('.mobile-menu');
  const navLinks = document.querySelector('.nav-links');
  
  mobileMenu.addEventListener('click', () => {
    navLinks.classList.toggle('active');
  });

  // Sample portfolio data
  let portfolio = [];

  // Add holding form handler
  const addHoldingForm = document.getElementById('add-holding-form');
  addHoldingForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const symbol = document.getElementById('symbol').value.toUpperCase();
    const shares = parseFloat(document.getElementById('shares').value);
    const price = parseFloat(document.getElementById('price').value);

    addHolding(symbol, shares, price);
    updatePortfolioDisplay();
    addHoldingForm.reset();
  });

  function addHolding(symbol, shares, price) {
    const holding = {
      symbol,
      shares,
      price,
      currentPrice: price, // In a real app, this would be fetched from an API
      value: shares * price,
      change: 0
    };
    
    portfolio.push(holding);
  }

  function updatePortfolioDisplay() {
    const holdingsBody = document.getElementById('holdings-body');
    const totalValue = portfolio.reduce((sum, holding) => sum + holding.value, 0);
    const totalChange = portfolio.reduce((sum, holding) => sum + holding.change, 0);

    // Update summary cards
    document.querySelector('.total-value .amount').textContent = 
      formatCurrency(totalValue);
    document.querySelector('.daily-change .amount').textContent = 
      formatCurrency(totalChange);

    // Update holdings table
    holdingsBody.innerHTML = portfolio.map(holding => `
      <tr>
        <td>${holding.symbol}</td>
        <td>${holding.shares}</td>
        <td>${formatCurrency(holding.currentPrice)}</td>
        <td>${formatCurrency(holding.value)}</td>
        <td class="${holding.change >= 0 ? 'success' : 'danger'}">
          ${formatCurrency(holding.change)}
        </td>
      </tr>
    `).join('');
  }

  function formatCurrency(amount) {
    return new Intl.NumberFormat('en-US', {
      style: 'currency',
      currency: 'USD'
    }).format(amount);
  }

  // Add some sample data
  addHolding('AAPL', 10, 150.50);
  addHolding('GOOGL', 5, 2750.25);
  updatePortfolioDisplay();
});
